@@ -86,6 +86,13 @@ class SignaldAPI(SignaldGeneratedAPI):
             and response.get("data", {}).get("username") == username,
         )
 
+    async def list_accounts(self) -> JsonAccountListv0:
+        data = await self.get_response({"type": "list_accounts"})
+        return JsonAccountListv0(**data)
+
     def handle_message(self, payload):
         envelope = JsonMessageEnvelopev1(**payload.get("data", dict()))
+        self.handle_envelope(envelope)
+
+    def handle_envelope(self, envelope):
         print(envelope)
